==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AdditionalNetworkDefinitionBuilder extends io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluentImpl<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition,io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionBuilder>{
  public AdditionalNetworkDefinitionBuilder() {
    this(false);
  }
  public AdditionalNetworkDefinitionBuilder(java.lang.Boolean validationEnabled) {
    this(new AdditionalNetworkDefinition(), validationEnabled);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent) {
    this(fluent, false);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AdditionalNetworkDefinition(), validationEnabled);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance) {
    this(fluent, instance, false);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withRawCNIConfig(instance.getRawCNIConfig()); 
    fluent.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance) {
    this(instance,false);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withRawCNIConfig(instance.getRawCNIConfig()); 
    this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition build() {
    AdditionalNetworkDefinition buildable = new AdditionalNetworkDefinition(fluent.getName(),fluent.getNamespace(),fluent.getRawCNIConfig(),fluent.getSimpleMacvlanConfig(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AdditionalNetworkDefinitionBuilder that = (AdditionalNetworkDefinitionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AdditionalNetworkDefinitionBuilder extends io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluentImpl<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition,io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionBuilder>{
  public AdditionalNetworkDefinitionBuilder() {
    this(false);
  }
  public AdditionalNetworkDefinitionBuilder(java.lang.Boolean validationEnabled) {
    this(new AdditionalNetworkDefinition(), validationEnabled);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent) {
    this(fluent, false);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AdditionalNetworkDefinition(), validationEnabled);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance) {
    this(fluent, instance, false);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withRawCNIConfig(instance.getRawCNIConfig()); 
    fluent.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance) {
    this(instance,false);
  }
  public AdditionalNetworkDefinitionBuilder(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withRawCNIConfig(instance.getRawCNIConfig()); 
    this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition build() {
    AdditionalNetworkDefinition buildable = new AdditionalNetworkDefinition(fluent.getName(),fluent.getNamespace(),fluent.getRawCNIConfig(),fluent.getSimpleMacvlanConfig(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AdditionalNetworkDefinitionBuilder that = (AdditionalNetworkDefinitionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
